fedex.services

Package fedex :: Package services |
[hide private]
[frames] | no frames]

# Package services

source code

This module contains the wrappers around Fedex Web Service requests which you will want to instantiate and use with a FedexConfig object supplying your static details. Each module here corresponds to a Fedex WSDL.

Submodules | [hide private]
fedex.services.address_validation_service: This package contains the shipping methods defined by Fedex's AddressValidationService WSDL file. fedex.services.package_movement: This package contains classes to check service availability, route, and postal codes. fedex.services.rate_service: This package contains classes to request pre-ship rating information and to determine estimated or courtesy billing quotes. fedex.services.ship_service: This package contains the shipping methods defined by Fedex's ShipService WSDL file. fedex.services.track_service: This package contains the shipment tracking methods defined by Fedex's TrackService WSDL file.

Variables | [hide private]
| __package__ = `None`